## Challenge
Create a modal with some information and a button. Maybe a Welcome to the app with an image and a button. Make it look proportional with the modal size and text on difference device screens (test on desktop web, then test on iPad and mobile)
## Hint - Responsive Font Size - Font Scale (Method 1)
```
import React from 'react';
import { View, Text, StyleSheet, useWindowDimensions } from 'react-native';

const ResponsiveText = () => {
  const { fontScale } = useWindowDimensions();

  // Define a base font size
  const baseFontSize = 20;

  // Adjust the font size according to the font scale
  const scaledFontSize = baseFontSize / fontScale;

  return (
    <View style={styles.container}>
      <Text style={[styles.text, { fontSize: scaledFontSize }]}>
        This is responsive text!
      </Text>
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
  },
  text: {
    fontWeight: 'bold',
  },
});

export default ResponsiveText;
```

**Explanation:**

- **useWindowDimensions Hook:** This hook provides `fontScale`, which reflects the user's font size preferences. By dividing your base font size by `fontScale`, you ensure that the text appears consistent across different devices, regardless of user settings.
    
- **Dynamic Font Size Calculation:** The `scaledFontSize` is calculated by dividing the base font size by the `fontScale`. This ensures that the text remains proportional and respects the user's accessibility settings without disrupting the design

## Hint - Responsive Font Size - Pixel Ratio (Or Method 2)
```
import React from 'react';
import { View, Text, StyleSheet, PixelRatio } from 'react-native';

const ResponsiveDesign = () => {
  // Define a base size for your design
  const baseSize = 16;

  // Adjust the size according to the pixel ratio
  const adjustedSize = PixelRatio.getPixelSizeForLayoutSize(baseSize);

  return (
    <View style={styles.container}>
      <Text style={[styles.text, { fontSize: adjustedSize }]}>
        This is pixel ratio responsive text!
      </Text>
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
  },
  text: {
    fontWeight: 'bold',
  },
});

export default ResponsiveDesign;

```

**Explanation:**

- **PixelRatio.getPixelSizeForLayoutSize:** This function converts a layout size in "density-independent pixels" (dp) to the equivalent size in physical pixels, based on the screen's pixel density [3](https://blog.stackademic.com/react-native-achieving-responsiveness-through-scalable-fonts-dimensions-and-pixels-5123a7b66cc0)[9](https://reactnative.dev/docs/pixelratio). By using this method, you ensure the sizes are automatically adjusted according to the device's pixel ratio, which helps maintain a consistent appearance across various devices with high or low pixel densities.
    
- **Dynamic Font Size Adjustment:** In this example, `adjustedSize` is calculated using `PixelRatio.getPixelSizeForLayoutSize(baseSize)`. This ensures that your text and other UI elements are scaled appropriately for different pixel densities.
## Hint - Responsive Sizes of Modal

Refer to [[React Native - Modal Responsive with Shadow Background]]

---

## **Hint References**

- Modal - https://reactnative.dev/docs/modal
- Pixel Ratio - [https://reactnative.dev/docs/pixelratio](https://reactnative.dev/docs/pixelratio)  
- Font Scale - [https://medium.com/@runawaytrike/font-scaling-in-react-native-apps-8d38a48fdf26](https://medium.com/@runawaytrike/font-scaling-in-react-native-apps-8d38a48fdf26)
